bayespy.inference.vmp.nodes.constant.Constant.lower_bound_contribution
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.lower_bound_contribution